nth-boilerplate
===============

## WHAT
- a simple, very opinionated boilerplate that let's you start coding very fast
- uses html5 and compass (see complete list in humans.txt) 
- custom 960 grid system (media queries created for basic breakpoints).
- prepared for Mobile first
- grunt.js is used to lint/concat/min js (sass to css is performed through compass now, since contrib-sass is too slow for production at the moment)
- grunt can live reload your browser while you change code (you will need toe LiveReload extension)

A basic version without the grunt.js configuration is found at the [gruntless branch](https://github.com/zigotica/nth-boilerplate/tree/gruntless) in this repo. Note: basic version will not be updated with repo changes.

## WHY! 
Hell, everyone has their own boilerplate, right? 

## HOW
### The grid
For each media query you have to define a grid as in:
```
  $grid-columns: 8;
  $grid-gutter-width: 20px;
  $grid-total-width: 320px; 
  // this is calculated automatically:
  $grid-col-width: ( $grid-total-width / $grid-columns) - $grid-gutter-width;
```
In this example columns will measure 20px width (calculated by compass), and will have 10px space around them since we are using half the gutter for side margins. This way you dont have to care about first or last elements spanning to several rows, every block will accomodate accordingly. Total content space will be 300px although you can use 100% width as well.

### Semantics
Did I hear semantic grid system? It's pretty easy, instead of adding .col12 or .span4 classes to your markup, I prefer to set the measures/distances using a self-made compass mixin, as in: 
```
.wrapper { @include gridcol($grid-columns); } /* takes all space except the outer margins */
.box { @include gridcol(4); } /* spans 4 columns */
.menu { @include gridcol(4, 1); } /* spans 4 columns, leaving 1 column gap on the left */
.ul { @include gridcol(3, 0, 20px); } /* spans 3 columns, leaving 20px gap on the left */
.social { @include gridcol(4, 0, -10px, right); } /* spans 4 columns and forces to float right w/o the margin */
```
This way my markup will be semantic since I'm not adding size-meaning to elements that will change measures with media queries. The mixin applied to `@include gridcol(4)` is:
```
@mixin gridcol($n, $colsgap:0, $offset:0, $float: left) {
  $gap : $colsgap * ($grid-gutter-width + $grid-col-width);
  display: inline-block;
  float: $float;
  @if $float == "right" {
    margin-right: ( $grid-gutter-width / 2 ) + $offset + $gap;
    margin-left: ( $grid-gutter-width / 2 );
  }
  @else {
    margin-left: ( $grid-gutter-width / 2 ) + $offset + $gap;
    margin-right: ( $grid-gutter-width / 2 );
  }
  width: ( ($grid-gutter-width + $grid-col-width) * $n ) - $grid-gutter-width;
}
```
### Goodies
- There's a `debug` class applied to html element to show specific background colors that are ment to test boxes width/height.
- You can optionally test your layout using the grid.js that will paint columns for each media query. This has been moved to grunt.js now (you will need to add grid.js to the build process)

## BUILD PROCESS
Grunt will be used to lint (jshint), concatenate and minify the final scripts. We use config.rb to convert sass to css since it is much faster than current contrib-sass module.
### Install Grunt and other packages
If you haven't yet, you will need to install [Grunt](https://github.com/gruntjs/grunt) (globally) typing `npm install -g grunt`  (it requires npm).
To install the other packages (locally):

```
  npm install grunt-reload
```
This will add a node_modules folder in your project with subfolders including the packages. This is the recommended approach (from Grunt creator) since using globally installed packages can cause compatibility issues among different projects. To avoid distributing these packages in your project just add them into your .gitignore file, as in `node_modules/*` (you might also want to avoid distributing your grunt file and sources folder)

### Build and Live Reload
- You can build the project by typing `grunt` in your terminal. 
- You can also use the live-reload feature by typing `grunt live`. In this case a proxy server will be created, running at `http://localhost:35729`. We are using the LiveReload extension now, since the previous module proxy approach was giving random results (sometimes reload was not triggered). 

Please note that if you are already running the proxy server and make a change in grunt.js configuration file, you will need to close the proxy `CTRL+C`, restart it `grunt live` and also manually reload the page at `http://localhost:35729`. This does not apply to changes in html, js or scss files (that's why we use the live-reload!).

## Dependencies
- [Compass](http://compass-style.org/)
- [Grunt](https://github.com/gruntjs/grunt) (requires npm)
- [grunt-reload](https://github.com/webxl/grunt-reload)
- [Live Reload](http://feedback.livereload.com/)

## Complaints?
Use the issue tracker, send pull requests, the usual polite manners. Thanx.

## License
Eat it, burn it, use it at your own risk. Or even better, dont use it! ^_^
