module.exports = function(grunt) {

  // define Javascript source/destination paths:
  var SOURCE_JS   = "sources/js/",
      BUILD_JS    = "public/js/",
      SOURCE_CSS  = "public/css/",
      BUILD_CSS   = "public/css/";

  // Project configuration.
  grunt.initConfig({
    lint: {
      files: [SOURCE_JS + 'ours/*.js']
    },
    jshint: {
      options: {
        laxcomma: true,
        boss: true
      }
    },

    concat: {
      js: {
        //src: [SOURCE_JS+'theirs/respond.min.js', SOURCE_JS+'theirs/is.event.supported.js', SOURCE_JS+'ours/main.js', SOURCE_JS+'ours/grids/grid.js'],
        src: [SOURCE_JS+'theirs/respond.min.js', SOURCE_JS+'theirs/is.event.supported.js', SOURCE_JS+'ours/main.js'],
        dest: SOURCE_JS+'app.js'
      },
      css: {
        src: [SOURCE_CSS+'styles.css', SOURCE_CSS+'menus.css' ],
        dest: BUILD_CSS+'all.css'        
      }
    },

    meta: {
      banner: '/*! main javascript file, by Sergi Meseguer @zigotica - https://github.com/zigotica/_______________ */'
          + '\n' + '/*! minified by grunt.js */'
    },
    min: {
      dist: {
        src: ['<banner>',SOURCE_JS+'app.js'],
        dest: BUILD_JS+'app.min.js'
      }
    },
    uglify: {
      mangle: {toplevel: true},
      squeeze: {dead_code: true},
      codegen: {quote_keys: true}
    },

    sass: { 
      dist: { 
        options: { 
          compass: true,
          style: 'compressed',
          precision: 99,
          noCache: true
        },
        files: {
          'public/css/styles.css' : 'sources/compass/styles.scss',
          'public/css/menus.css' : 'sources/compass/menus.scss',
          'public/css/forms.css' : 'sources/compass/forms.scss',
          'public/css/tables.css' : 'sources/compass/tables.scss',
          'public/css/widgets.css' : 'sources/compass/widgets.scss'
        }
      }
    },

    server: {
      port: 8000,
      base: '.'
    },
    reload: {
      port: 35729,
      liveReload: {}
    },
    watch:{
      // contrib-sass is too slow, we'll be using compass watch instead for now
      files:['*.html', 'public/css/*.css', 'sources/js/*.js'],
      tasks:'default reload'
    }

  });

  var connect = require('connect');

  grunt.loadNpmTasks('grunt-contrib-sass');
  grunt.loadNpmTasks('grunt-reload');

  grunt.registerTask('default', 'lint concat min sass');
  grunt.registerTask('live', 'server reload watch');
};
